@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -24,7 +24,7 @@ public:
 
     void start();
 
-    LdapWidgetItem *ldapWidgetItem() const;
+    [[nodiscard]] LdapWidgetItem *ldapWidgetItem() const;
     void setLdapWidgetItem(LdapWidgetItem *ldapWidgetItem);
 
     [[nodiscard]] int currentIndex() const;
